@@ -276,13 +276,13 @@ static const gchar *ui_info =
 "      <menuitem action='AsMinor'/>"
 "    </menu>"
 "    <menu action='ManageMenu'>"
-//"      <menuitem action='Currency'/>"
 "      <menuitem action='Account'/>"
 "      <menuitem action='Payee'/>"
 "      <menuitem action='Category'/>"
 "      <menuitem action='Archive'/>"
 "      <menuitem action='Budget'/>"
 "      <menuitem action='Assign'/>"
+//"      <menuitem action='Currency'/>"
 "    </menu>"
 "    <menu action='TxnMenu'>"
 "      <menuitem action='ShowOpe'/>"
@@ -1075,6 +1075,8 @@ gint account, count;
 				ope->date = GLOBALS->today;
 		}
 
+		// normally we can't be in addkeep without initialized ope with add
+
 		deftransaction_set_transaction(window, ope);
 
 		result = gtk_dialog_run (GTK_DIALOG (window));
@@ -2140,6 +2142,9 @@ gint flags;
 		gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (data->LV_acc), PREFS->rules_hint);
 		gtk_tree_view_columns_autosize (GTK_TREE_VIEW(data->LV_acc));
 
+		gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (data->LV_upc), PREFS->rules_hint);
+		gtk_tree_view_columns_autosize (GTK_TREE_VIEW(data->LV_upc));
+
 		DB( g_print(" - show toolbar=%d\n", PREFS->wal_toolbar) );
 		if(PREFS->wal_toolbar)
 			gtk_widget_show(GTK_WIDGET(data->toolbar));
@@ -2662,60 +2667,60 @@ static GtkWidget *ui_mainwindow_create_topspending(struct hbfile_data *data)
 GtkWidget *mainvbox, *hbox, *vbox;
 GtkWidget *label, *align, *widget;
 
-		mainvbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
-		data->GR_top = mainvbox;
+	mainvbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
+	data->GR_top = mainvbox;
 
-		label = make_label(_("Where your money goes"), 0.0, 0.5);
-		gimp_label_set_attributes(GTK_LABEL(label), PANGO_ATTR_WEIGHT, PANGO_WEIGHT_BOLD, -1);
-		gtk_misc_set_padding (GTK_MISC(label), SPACING_SMALL, SPACING_SMALL/2);
-	    gtk_box_pack_start (GTK_BOX (mainvbox), label, FALSE, FALSE, 0);
+	label = make_label(_("Where your money goes"), 0.0, 0.5);
+	gimp_label_set_attributes(GTK_LABEL(label), PANGO_ATTR_WEIGHT, PANGO_WEIGHT_BOLD, -1);
+	gtk_misc_set_padding (GTK_MISC(label), SPACING_SMALL, SPACING_SMALL/2);
+    gtk_box_pack_start (GTK_BOX (mainvbox), label, FALSE, FALSE, 0);
 
-		align = gtk_alignment_new(0, 0, 1.0, 1.0);
-		// top, bottom, left, right
-		gtk_alignment_set_padding (GTK_ALIGNMENT(align), 0, SPACING_SMALL, 2*SPACING_SMALL, SPACING_SMALL);
-		gtk_box_pack_start (GTK_BOX (mainvbox), align, TRUE, TRUE, 0);
+	align = gtk_alignment_new(0, 0, 1.0, 1.0);
+	// top, bottom, left, right
+	gtk_alignment_set_padding (GTK_ALIGNMENT(align), 0, SPACING_SMALL, 2*SPACING_SMALL, SPACING_SMALL);
+	gtk_box_pack_start (GTK_BOX (mainvbox), align, TRUE, TRUE, 0);
 
-		vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, SPACING_SMALL);
-		gtk_container_add (GTK_CONTAINER (align), vbox);
-		
-		/* total + date range */
-		hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, SPACING_SMALL);
-		gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
-		
-		label = make_label(_("Top spending"), 0.0, 0.5);
-		gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
-		
-		label = make_label(NULL, 0.0, 0.5);
-		data->TX_topamount = label;
-		gtk_box_pack_start (GTK_BOX (hbox), label, TRUE, TRUE, 0);
+	vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, SPACING_SMALL);
+	gtk_container_add (GTK_CONTAINER (align), vbox);
+	
+	/* total + date range */
+	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, SPACING_SMALL);
+	gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
+	
+	label = make_label(_("Top spending"), 0.0, 0.5);
+	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
+	
+	label = make_label(NULL, 0.0, 0.5);
+	data->TX_topamount = label;
+	gtk_box_pack_start (GTK_BOX (hbox), label, TRUE, TRUE, 0);
 
-		data->CY_range = make_daterange(label, FALSE);
-		gtk_box_pack_end (GTK_BOX (hbox), data->CY_range, FALSE, FALSE, 0);
+	data->CY_range = make_daterange(label, FALSE);
+	gtk_box_pack_end (GTK_BOX (hbox), data->CY_range, FALSE, FALSE, 0);
 
-		widget = make_radio(CYA_CATSUBCAT, TRUE, GTK_ORIENTATION_HORIZONTAL);
-		data->RA_type = widget;
-		gtk_box_pack_end (GTK_BOX (hbox), widget, FALSE, FALSE, 0);
+	widget = make_radio(CYA_CATSUBCAT, TRUE, GTK_ORIENTATION_HORIZONTAL);
+	data->RA_type = widget;
+	gtk_box_pack_end (GTK_BOX (hbox), widget, FALSE, FALSE, 0);
 
-		/* pie + listview */
-		hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
-		gtk_box_pack_start (GTK_BOX (vbox), hbox, TRUE, TRUE, 0);
+	/* pie + listview */
+	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
+	gtk_box_pack_start (GTK_BOX (vbox), hbox, TRUE, TRUE, 0);
 
-		widget = gtk_chart_new(CHART_TYPE_PIE);
-		data->RE_pie = widget;
-		gtk_chart_set_minor_prefs(GTK_CHART(widget), PREFS->euro_value, PREFS->minor_cur.symbol);
-		gtk_box_pack_start (GTK_BOX (hbox), widget, TRUE, TRUE, 0);
+	widget = gtk_chart_new(CHART_TYPE_PIE);
+	data->RE_pie = widget;
+	gtk_chart_set_minor_prefs(GTK_CHART(widget), PREFS->euro_value, PREFS->minor_cur.symbol);
+	gtk_box_pack_start (GTK_BOX (hbox), widget, TRUE, TRUE, 0);
 
 /*
-		sw = gtk_scrolled_window_new (NULL, NULL);
-		gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (sw), GTK_SHADOW_ETCHED_IN);
-		gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
-		gtk_box_pack_start (GTK_BOX (hbox), sw, FALSE, FALSE, 0);
-		*/
-		
-		widget = (GtkWidget *)create_list_topspending();
-		data->LV_top = widget;
+	sw = gtk_scrolled_window_new (NULL, NULL);
+	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (sw), GTK_SHADOW_ETCHED_IN);
+	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+	gtk_box_pack_start (GTK_BOX (hbox), sw, FALSE, FALSE, 0);
+	*/
+	
+	widget = (GtkWidget *)create_list_topspending();
+	data->LV_top = widget;
 
-		gtk_chart_show_legend(GTK_CHART(data->RE_pie), TRUE, TRUE);
+	gtk_chart_show_legend(GTK_CHART(data->RE_pie), TRUE, TRUE);
 	
 //		gtk_container_add (GTK_CONTAINER (sw), widget);
 
@@ -2837,18 +2842,6 @@ GtkAction *action;
 	data->window = window;
 	GLOBALS->mainwindow = window;
 
-	//setup, init and show window
-	wg = &PREFS->wal_wg;
-	if(wg->s == 0)
-	{
-		gtk_window_move(GTK_WINDOW(window), wg->l, wg->t);
-		gtk_window_resize(GTK_WINDOW(window), wg->w, wg->h);
-	}
-	else
-		gtk_window_maximize(GTK_WINDOW(window));
-
-	gtk_widget_show (window);
-
 	mainvbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
 	gtk_container_add (GTK_CONTAINER (window), mainvbox);
 
@@ -2895,6 +2888,16 @@ GtkWidget *bar, *label;
 	if(PREFS->wal_vpaned > 0)
 		gtk_paned_set_position(GTK_PANED(data->vpaned), PREFS->wal_vpaned);
 
+	//setup, init and show window
+	wg = &PREFS->wal_wg;
+	if(wg->s == 0)
+	{
+		gtk_window_move(GTK_WINDOW(window), wg->l, wg->t);
+		gtk_window_resize(GTK_WINDOW(window), wg->w, wg->h);
+	}
+	else
+		gtk_window_maximize(GTK_WINDOW(window));
+
 	gtk_widget_show_all (window);
 	
 	//todo: move this elsewhere
