@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2015 Maxime DOYEN
+ *  Copyright (C) 1995-2016 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -20,11 +20,7 @@
 #ifndef __GTK_CHART_H__
 #define __GTK_CHART_H__
 
-#include <glib.h>
-#include <gdk/gdk.h>
-#include <gtk/gtk.h>
-#include <cairo.h>
-#include <math.h>
+#include "gtk-chart-colors.h"
 
 G_BEGIN_DECLS
 #define GTK_TYPE_CHART            (gtk_chart_get_type ())
@@ -152,10 +148,8 @@ struct _GtkChart
 	gchar		*minor_symbol;
 
 	/* color datas */
-	struct rgbcol		*colors;
-	gint	nb_cols;
-	gint	cs_red, cs_green, cs_blue, cs_yellow;
-
+	GtkColorScheme color_scheme;
+	
 	/* cairo default value */
 	PangoFontDescription *pfd;
 	gint				pfd_size;
