@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2015 Maxime DOYEN
+ *  Copyright (C) 1995-2016 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -72,14 +72,14 @@ enum
 {
 	ACC_TYPE_NONE       = 0,
 	ACC_TYPE_BANK       = 1,	//Banque
-	ACC_TYPE_CASH       = 2,	//Espce
+	ACC_TYPE_CASH       = 2,	//Espèce
 	ACC_TYPE_ASSET      = 3,	//Actif (avoir)
-	ACC_TYPE_CREDITCARD = 4,	//Carte crdit
+	ACC_TYPE_CREDITCARD = 4,	//Carte crédit
 	ACC_TYPE_LIABILITY  = 5,	//Passif (dettes)
 //	ACC_TYPE_STOCK      = 6,	//Actions
 //	ACC_TYPE_MUTUALFUND = 7,	//Fond de placement
 //	ACC_TYPE_INCOME     = 8,	//Revenus
-//	ACC_TYPE_EXPENSE    = 9,	//Dpenses
+//	ACC_TYPE_EXPENSE    = 9,	//Dépenses
 //	ACC_TYPE_EQUITY     = 10,	//Capitaux propres
 //	ACC_TYPE_,
 	ACC_TYPE_MAXVALUE
