@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2015 Maxime DOYEN
+ *  Copyright (C) 1995-2016 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -37,7 +37,7 @@ struct _archive
 
 	//guint32		date;
 	//gushort		pos;
-	gushort     status;
+	gushort     status, _pad1;
 	//gchar		*info;
 	//guint32		*tags;
 	//guint32		kxfer;		//strong link xfer key
