@@ -35,6 +35,7 @@ struct _category
 
 	/* unsaved datas */
 	gboolean	filter;
+	guint		usage_count;
 	gboolean	imported;
 };
 
@@ -69,7 +70,8 @@ void da_cat_consistency(Category *item);
 
 GList *category_glist_sorted(gint column);
 
-gboolean category_is_used(guint32 key);
+void category_delete_unused(void);
+void category_fill_usage(void);
 void category_move(guint32 key1, guint32 key2);
 gboolean category_rename(Category *item, const gchar *newname);
 gint category_change_type(Category *item, gboolean isIncome);
