@@ -304,29 +304,61 @@ da_pay_debug_list(void)
 
 /* = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = */
 
-
-
-
-gboolean
-payee_is_used(guint32 key)
+void 
+payee_delete_unused(void)
 {
+GList *lpay, *list;
+	
+	lpay = list = g_hash_table_get_values(GLOBALS->h_pay);
+	while (list != NULL)
+	{
+	Payee *entry = list->data;
+
+		if(entry->usage_count <= 0 && entry->key > 0)
+			da_pay_remove (entry->key);
+		list = g_list_next(list);
+	}
+	g_list_free(lpay);
+}
+
+
+void 
+payee_fill_usage(void)
+{
+GList *lpay;
 GList *lrul, *list;
 
+	lpay = list = g_hash_table_get_values(GLOBALS->h_pay);
+	while (list != NULL)
+	{
+	Payee *entry = list->data;
+		entry->usage_count = 0;
+		list = g_list_next(list);
+	}
+	g_list_free(lpay);
+
+
 	list = g_list_first(GLOBALS->ope_list);
 	while (list != NULL)
 	{
 	Transaction *entry = list->data;
-		if( key == entry->kpay )
-			return TRUE;
+	Payee *pay = da_pay_get (entry->kpay);
+
+		if(pay)
+			pay->usage_count++;
+		
 		list = g_list_next(list);
 	}
 
+
 	list = g_list_first(GLOBALS->arc_list);
 	while (list != NULL)
 	{
 	Archive *entry = list->data;
-		if( key == entry->kpay )
-			return TRUE;
+	Payee *pay = da_pay_get (entry->kpay);
+		
+		if(pay)
+			pay->usage_count++;
 		list = g_list_next(list);
 	}
 
@@ -334,17 +366,18 @@ GList *lrul, *list;
 	while (list != NULL)
 	{
 	Assign *entry = list->data;
+	Payee *pay = da_pay_get (entry->kpay);
+
+		if(pay)
+			pay->usage_count++;
 
-		if( key == entry->kpay)
-			return TRUE;
 		list = g_list_next(list);
 	}
 	g_list_free(lrul);
 
-
-	return FALSE;
 }
 
+
 void
 payee_move(guint32 key1, guint32 key2)
 {
