@@ -849,6 +849,34 @@ gdouble exprate, incrate, balrate;
 					//trn_amount = to_base_amount(ope->amount, acc->kcur);
 					trn_amount = ope->amount;
 
+					//#1562372 in case of a split we need to take amount for filter categories only
+					if( ope->flags & OF_SPLIT )
+					{
+					guint nbsplit = da_transaction_splits_count(ope);
+					Split *split;
+					Category *catentry;
+					gint sinsert;
+
+						trn_amount = 0.0;
+
+						for(i=0;i<nbsplit;i++)
+						{
+							split = ope->splits[i];
+							catentry = da_cat_get(split->kcat);
+							if(catentry == NULL) continue;
+							sinsert = ( catentry->filter == TRUE ) ? 1 : 0;
+							if(data->filter->option[FILTER_CATEGORY] == 2) sinsert ^= 1;
+
+							DB( g_print(" split '%s' insert=%d\n",catentry->name, sinsert) );
+
+							if( (data->filter->option[FILTER_CATEGORY] == 0) || sinsert)
+							{
+								trn_amount += split->amount;
+							}
+						}
+
+					}
+
 					if( tmpfor != BY_REPDIST_TAG )
 					{
 						if( (tmpfor == BY_REPDIST_CATEGORY || tmpfor == BY_REPDIST_SUBCATEGORY) && ope->flags & OF_SPLIT )
