@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2015 Maxime DOYEN
+ *  Copyright (C) 1995-2016 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -53,6 +53,33 @@ static GtkWidget *ui_arc_listview_new(void);
 
 
 
+static void ui_arc_listview_select_by_pointer(GtkTreeView *treeview, gpointer user_data)
+{
+GtkTreeModel *model;
+GtkTreeIter	iter;
+GtkTreeSelection *selection;
+gboolean valid;
+Archive *arc = user_data;
+
+	model = gtk_tree_view_get_model(GTK_TREE_VIEW(treeview));
+	selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(treeview));
+
+	valid = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(model), &iter);
+	while (valid)
+	{
+	Archive *tmp_arc;
+
+		gtk_tree_model_get (model, &iter, LST_DEFARC_DATAS, &tmp_arc, -1);
+		if( arc == tmp_arc )
+		{
+			gtk_tree_selection_select_iter (selection, &iter);
+			break;
+		}
+	
+		valid = gtk_tree_model_iter_next(GTK_TREE_MODEL(model), &iter);
+	}
+}
+
 
 /*
 **
@@ -771,7 +798,7 @@ gint row;
 	gtk_grid_attach (GTK_GRID (group_grid), label, 0, 0, 3, 1);
 
 	row = 1;
-	label = make_label(_("_Amount:"), 0.0, 0.5);
+	label = make_label_widget(_("_Amount:"));
 	gtk_grid_attach (GTK_GRID (group_grid), label, 1, row, 1, 1);
 
 	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
@@ -786,7 +813,7 @@ gint row;
 	gtk_grid_attach (GTK_GRID (group_grid), hbox, 2, row, 1, 1);
 
 	row++;
-	label = make_label(_("Pay_ment:"), 0.0, 0.5);
+	label = make_label_widget(_("Pay_ment:"));
 	gtk_grid_attach (GTK_GRID (group_grid), label, 1, row, 1, 1);
 	widget = make_paymode(label);
 	gtk_widget_set_hexpand (widget, TRUE);
@@ -801,7 +828,7 @@ gint row;
 	/* info should be here some day */
 
 	row++;
-	label = make_label(_("A_ccount:"), 0.0, 0.5);
+	label = make_label_widget(_("A_ccount:"));
 	gtk_grid_attach (GTK_GRID (group_grid), label, 1, row, 1, 1);
 	widget = ui_acc_comboboxentry_new(label);
 	gtk_widget_set_hexpand (widget, TRUE);
@@ -809,7 +836,7 @@ gint row;
 	gtk_grid_attach (GTK_GRID (group_grid), widget, 2, row, 1, 1);
 
 	row++;
-	label = make_label(_("_To account:"), 0.0, 0.5);
+	label = make_label_widget(_("_To account:"));
 	data->LB_accto = label;
 	gtk_grid_attach (GTK_GRID (group_grid), label, 1, row, 1, 1);
 	widget = ui_acc_comboboxentry_new(label);
@@ -837,7 +864,7 @@ gint row;
 	gtk_grid_attach (GTK_GRID (group_grid), label, 0, 0, 3, 1);
 
 	row = 1;
-	label = make_label(_("_Payee:"), 0.0, 0.5);
+	label = make_label_widget(_("_Payee:"));
 	gtk_grid_attach (GTK_GRID (group_grid), label, 1, row, 1, 1);
 	widget = ui_pay_comboboxentry_new(label);
 	gtk_widget_set_hexpand (widget, TRUE);
@@ -845,7 +872,7 @@ gint row;
 	gtk_grid_attach (GTK_GRID (group_grid), widget, 2, row, 1, 1);
 
 	row++;
-	label = make_label(_("_Category:"), 0.0, 0.5);
+	label = make_label_widget(_("_Category:"));
 	gtk_grid_attach (GTK_GRID (group_grid), label, 1, row, 1, 1);
 	widget = ui_cat_comboboxentry_new(label);
 	gtk_widget_set_hexpand (widget, TRUE);
@@ -853,7 +880,7 @@ gint row;
 	gtk_grid_attach (GTK_GRID (group_grid), widget, 2, row, 1, 1);
 
 	row++;
-	label = make_label(_("_Memo:"), 0.0, 0.5);
+	label = make_label_widget(_("_Memo:"));
 	gtk_grid_attach (GTK_GRID (group_grid), label, 1, row, 1, 1);
 	widget = make_string(label);
 	gtk_widget_set_hexpand (widget, TRUE);
@@ -863,7 +890,7 @@ gint row;
 	/* tags should be here some day */
 
 	row++;
-	label = make_label(_("_Status:"), 0.0, 0.5);
+	label = make_label_widget(_("_Status:"));
 	gtk_grid_attach (GTK_GRID (group_grid), label, 1, row, 1, 1);
 	widget = make_cycle(label, CYA_TXN_STATUS);
 	data->CY_status = widget;
@@ -902,7 +929,7 @@ gint row;
 	gtk_grid_attach (GTK_GRID (group_grid), widget, 2, row, 1, 1);
 
 	row++;
-	label = gtk_label_new_with_mnemonic (_("Ever_y:"));
+	label = make_label_widget(_("Ever_y:"));
 	data->LB_every = label;
 	gtk_grid_attach (GTK_GRID (group_grid), label, 1, row, 1, 1);
 
@@ -918,7 +945,7 @@ gint row;
     gtk_box_pack_start (GTK_BOX (hbox), widget, TRUE, TRUE, 0);
 
 	row++;
-	label = make_label(_("Week end:"), 0.0, 0.5);
+	label = make_label_widget(_("Week end:"));
 	data->LB_weekend = label;
 	gtk_grid_attach (GTK_GRID (group_grid), label, 1, row, 1, 1);
 
@@ -946,7 +973,7 @@ gint row;
 }
 
 
-GtkWidget *ui_arc_manage_dialog (void)
+GtkWidget *ui_arc_manage_dialog (Archive *ext_arc)
 {
 struct ui_arc_manage_data data;
 GtkWidget *dialog, *content_area;
@@ -985,7 +1012,7 @@ gint w, h;
 	hgrid = gtk_grid_new ();
 	gtk_grid_set_row_spacing (GTK_GRID (hgrid), SPACING_SMALL);
 	gtk_grid_set_column_spacing (GTK_GRID (hgrid), SPACING_MEDIUM);
-	gtk_widget_set_margin_end(hgrid, SPACING_SMALL);
+	gtk_widget_set_margin_right(hgrid, SPACING_SMALL);
 	gtk_paned_pack1 (GTK_PANED(hpaned), hgrid, FALSE, FALSE);
 
 	// listview
@@ -1014,7 +1041,7 @@ gint w, h;
 	gtk_grid_set_row_spacing (GTK_GRID (content_grid), SPACING_LARGE);
 	gtk_orientable_set_orientation(GTK_ORIENTABLE(content_grid), GTK_ORIENTATION_VERTICAL);
 	//gtk_container_set_border_width (GTK_CONTAINER(content_grid), SPACING_MEDIUM);
-	gtk_widget_set_margin_start(content_grid, SPACING_SMALL);
+	gtk_widget_set_margin_left(content_grid, SPACING_SMALL);
 	gtk_paned_pack2 (GTK_PANED(hpaned), content_grid, FALSE, FALSE);
 
 	hgrid = gtk_grid_new ();
@@ -1061,6 +1088,9 @@ gint w, h;
 
 	gtk_widget_show_all (dialog);
 
+	if(ext_arc != NULL)
+		ui_arc_listview_select_by_pointer(GTK_TREE_VIEW(data.LV_arc), ext_arc);
+
 	//wait for the user
 	gint result = gtk_dialog_run (GTK_DIALOG (dialog));
 
