@@ -762,7 +762,7 @@ GtkWidget *container, *scrollwin, *hbox, *vbox, *label, *widget;
 	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrollwin), GTK_SHADOW_ETCHED_IN);
 	//gtk_container_set_border_width (GTK_CONTAINER(scrollwin), SPACING_SMALL);
 
-	data->LV_cat = (GtkWidget *)ui_cat_listview_new(TRUE);
+	data->LV_cat = (GtkWidget *)ui_cat_listview_new(TRUE, FALSE);
 	gtk_container_add(GTK_CONTAINER(scrollwin), data->LV_cat);
 
 	vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, SPACING_SMALL);
@@ -811,7 +811,7 @@ GtkWidget *container, *scrollwin, *hbox, *vbox, *label, *widget;
 	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrollwin), GTK_SHADOW_ETCHED_IN);
 	//gtk_container_set_border_width (GTK_CONTAINER(scrollwin), SPACING_SMALL);
 
-	data->LV_pay = (GtkWidget *)ui_pay_listview_new(TRUE);
+	data->LV_pay = (GtkWidget *)ui_pay_listview_new(TRUE, FALSE);
 	gtk_container_add(GTK_CONTAINER(scrollwin), data->LV_pay);
 
 	vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, SPACING_SMALL);
