@@ -27,6 +27,10 @@ enum
 	NUM_LST_DEFPAY
 };
 
+#define LST_DEFPAY_SORT_NAME	 1
+#define LST_DEFPAY_SORT_USED	 2
+
+
 struct ui_pay_manage_dialog_data
 {
 	GtkWidget	*window;
@@ -48,9 +52,9 @@ struct payPopContext
 };
 
 
-gchar *ui_pay_comboboxentry_get_name(GtkComboBox *entry_box);
 guint32 ui_pay_comboboxentry_get_key(GtkComboBox *entry_box);
 guint32 ui_pay_comboboxentry_get_key_add_new(GtkComboBox *entry_box);
+Payee *ui_pay_comboboxentry_get(GtkComboBox *entry_box);
 gboolean ui_pay_comboboxentry_set_active(GtkComboBox *entry_box, guint32 key);
 void ui_pay_comboboxentry_add(GtkComboBox *entry_box, Payee *pay);
 void ui_pay_comboboxentry_populate(GtkComboBox *entry_box, GHashTable *hash);
@@ -63,7 +67,7 @@ void ui_pay_listview_add(GtkTreeView *treeview, Payee *item);
 guint32 ui_pay_listview_get_selected_key(GtkTreeView *treeview);
 void ui_pay_listview_remove_selected(GtkTreeView *treeview);
 void ui_pay_listview_populate(GtkWidget *view);
-GtkWidget *ui_pay_listview_new(gboolean withtoggle);
+GtkWidget *ui_pay_listview_new(gboolean withtoggle, gboolean withcount);
 GtkWidget *ui_pay_manage_dialog (void);
 
 #endif
