@@ -1101,10 +1101,10 @@ const gchar *lang;
 	g_free(PREFS->date_format);
 	PREFS->date_format = g_strdup(gtk_entry_get_text(GTK_ENTRY(data->ST_datefmt)));
 
-	ui_gtk_entry_set_text(data->ST_num_symbol, PREFS->base_cur.symbol);
+	ui_gtk_entry_replace_text(data->ST_num_symbol, &PREFS->base_cur.symbol);
 	PREFS->base_cur.is_prefix = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_num_isprefix));
-	ui_gtk_entry_set_text(data->ST_num_decimalchar, PREFS->base_cur.decimal_char);
-	ui_gtk_entry_set_text(data->ST_num_groupingchar, PREFS->base_cur.grouping_char);
+	ui_gtk_entry_replace_text(data->ST_num_decimalchar, &PREFS->base_cur.decimal_char);
+	ui_gtk_entry_replace_text(data->ST_num_groupingchar, &PREFS->base_cur.grouping_char);
 	PREFS->base_cur.frac_digits = gtk_spin_button_get_value(GTK_SPIN_BUTTON(data->NB_num_fracdigits));
 
 	//PREFS->num_nbdecimal = gtk_spin_button_get_value(GTK_SPIN_BUTTON(data->NB_numnbdec));
@@ -1127,12 +1127,8 @@ const gchar *lang;
 
 	ui_gtk_entry_replace_text(data->ST_euro_symbol, &PREFS->minor_cur.symbol);
 	PREFS->minor_cur.is_prefix = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_euro_isprefix));
-	
-	g_free(PREFS->minor_cur.decimal_char);
-	PREFS->minor_cur.decimal_char  = g_strdup( gtk_entry_get_text(GTK_ENTRY(data->ST_euro_decimalchar)) );
-	
-	g_free(PREFS->minor_cur.grouping_char);
-	PREFS->minor_cur.grouping_char = g_strdup( gtk_entry_get_text(GTK_ENTRY(data->ST_euro_groupingchar)) );
+	ui_gtk_entry_replace_text(data->ST_euro_decimalchar, &PREFS->minor_cur.decimal_char);
+	ui_gtk_entry_replace_text(data->ST_euro_groupingchar, &PREFS->minor_cur.grouping_char);
 	PREFS->minor_cur.frac_digits = gtk_spin_button_get_value(GTK_SPIN_BUTTON(data->NB_euro_fracdigits));
 
 	PREFS->stat_byamount   = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_stat_byamount));
@@ -1224,7 +1220,8 @@ gint crow, row;
 	gtk_style_context_add_class (gtk_widget_get_style_context (GTK_WIDGET(widget)), GTK_STYLE_CLASS_LINKED);
 	gtk_box_pack_start (GTK_BOX (hbox), widget, TRUE, TRUE, 0);
 
-	widget = gtk_button_new_with_label("...");
+	//widget = gtk_button_new_with_label("...");
+	widget = gtk_button_new_from_icon_name(ICONNAME_FOLDER, GTK_ICON_SIZE_BUTTON);
 	data->BT_path_import = widget;
 	gtk_box_pack_start (GTK_BOX (hbox), widget, FALSE, FALSE, 0);
 
@@ -1242,7 +1239,8 @@ gint crow, row;
 	gtk_style_context_add_class (gtk_widget_get_style_context (GTK_WIDGET(widget)), GTK_STYLE_CLASS_LINKED);
 	gtk_box_pack_start (GTK_BOX (hbox), widget, TRUE, TRUE, 0);
 
-	widget = gtk_button_new_with_label("...");
+	//widget = gtk_button_new_with_label("...");
+	widget = gtk_button_new_from_icon_name(ICONNAME_FOLDER, GTK_ICON_SIZE_BUTTON);
 	data->BT_path_export = widget;
 	gtk_box_pack_start (GTK_BOX (hbox), widget, FALSE, FALSE, 0);
 
@@ -1911,7 +1909,8 @@ gint crow, row;
 	gtk_style_context_add_class (gtk_widget_get_style_context (GTK_WIDGET(widget)), GTK_STYLE_CLASS_LINKED);
 	gtk_box_pack_start (GTK_BOX (hbox), widget, TRUE, TRUE, 0);
 
-	widget = gtk_button_new_with_label("...");
+	//widget = gtk_button_new_with_label("...");
+	widget = gtk_button_new_from_icon_name(ICONNAME_FOLDER, GTK_ICON_SIZE_BUTTON);
 	data->BT_path_hbfile = widget;
 	gtk_box_pack_start (GTK_BOX (hbox), widget, FALSE, FALSE, 0);
 
@@ -2021,7 +2020,6 @@ GtkWidget *defpref_dialog_new (void)
 {
 struct defpref_data data;
 GtkWidget *window, *content, *mainvbox;
-
 GtkWidget *hbox, *vbox, *sw, *widget, *notebook, *page, *ebox, *image, *label;
 
       window = gtk_dialog_new_with_buttons (_("Preferences"),
@@ -2073,8 +2071,22 @@ GtkWidget *hbox, *vbox, *sw, *widget, *notebook, *page, *ebox, *image, *label;
 	gtk_widget_show (vbox);
 
 	ebox = gtk_event_box_new();
-	gtk_style_context_add_class (gtk_widget_get_style_context (ebox), GTK_STYLE_CLASS_LIST_ROW);
-	gtk_widget_set_state_flags(ebox, GTK_STATE_FLAG_SELECTED, TRUE);
+	gtk_widget_set_name(ebox, "hbebox");
+	GtkStyleContext *context = gtk_widget_get_style_context (ebox);
+	#if GTK_MINOR_VERSION <= 18
+		gtk_style_context_add_class (context, GTK_STYLE_CLASS_LIST_ROW);
+		gtk_widget_set_state_flags(ebox, GTK_STATE_FLAG_SELECTED, TRUE);
+	#else
+	GtkCssProvider *provider;
+		provider = gtk_css_provider_new ();
+		gtk_css_provider_load_from_data (provider, 
+		"#hbebox { color: @theme_selected_fg_color; background-color: @theme_selected_bg_color; }"
+		, -1, NULL);
+		gtk_style_context_add_provider (context, GTK_STYLE_PROVIDER(provider), G_MAXUINT);
+	
+	//	gtk_style_context_set_state(context, GTK_STATE_FLAG_SELECTED);
+	#endif
+
 	gtk_box_pack_start (GTK_BOX (vbox), ebox, FALSE, TRUE, 0);
 	gtk_widget_show (ebox);
 
