@@ -265,6 +265,25 @@ GtkWidget *entry;
 }
 
 
+GtkWidget *make_search(GtkWidget *label)
+{
+GtkWidget *entry;
+
+	entry = gtk_entry_new ();
+	gtk_entry_set_placeholder_text(GTK_ENTRY(entry), _("type to search") );
+	gtk_entry_set_icon_from_icon_name (GTK_ENTRY (entry), GTK_ENTRY_ICON_PRIMARY, ICONNAME_FIND);
+	gtk_entry_set_icon_from_icon_name (GTK_ENTRY (entry), GTK_ENTRY_ICON_SECONDARY, ICONNAME_CLEAR);
+
+	gtk_entry_set_icon_sensitive (GTK_ENTRY(entry), GTK_ENTRY_ICON_SECONDARY, FALSE);
+
+	if(label)
+		gtk_label_set_mnemonic_widget (GTK_LABEL(label), entry);
+
+	return entry;
+}
+
+
+
 /*
 **
 */
@@ -614,6 +633,7 @@ guint i;
 	return combobox;
 }
 
+/* = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = */
 
 /*
 **
